#[repr(transparent)]pub struct GlobalAccountData {
inner: TypedObjectRef<GlobalAccountData, ()>,
phantom: PhantomData<()>,
}Expand description
The settings in the global account data of a Session.
GLib type: GObject with reference counted clone semantics.
Fields
inner: TypedObjectRef<GlobalAccountData, ()>phantom: PhantomData<()>Implementations
Sourceimpl GlobalAccountData
impl GlobalAccountData
Sourcepub fn session(&self) -> <OnceCell<Session> as Property>::Value
pub fn session(&self) -> <OnceCell<Session> as Property>::Value
The session this account data belongs to.
Sourcepub fn invite_avatars_enabled(&self) -> <Cell<bool> as Property>::Value
pub fn invite_avatars_enabled(&self) -> <Cell<bool> as Property>::Value
Whether to display avatars in invites.
Sourcepub fn connect_session_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_session_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the session property
Sourcepub fn connect_invite_avatars_enabled_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_invite_avatars_enabled_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the invite-avatars-enabled property
Sourcepub fn notify_session(&self)
pub fn notify_session(&self)
Notify listeners of a change in the session property
Sourcepub fn notify_invite_avatars_enabled(&self)
pub fn notify_invite_avatars_enabled(&self)
Notify listeners of a change in the invite-avatars-enabled property
Sourceimpl GlobalAccountData
impl GlobalAccountData
Sourcepub(crate) fn new(session: &Session) -> Self
pub(crate) fn new(session: &Session) -> Self
Create a new GlobalAccountData for the given session.
Sourcepub(crate) fn media_previews_enabled(&self) -> MediaPreviews
pub(crate) fn media_previews_enabled(&self) -> MediaPreviews
Which rooms display media previews.
Sourcepub(crate) fn should_room_show_media_previews(&self, room: &Room) -> bool
pub(crate) fn should_room_show_media_previews(&self, room: &Room) -> bool
Whether the given room should display media previews.
Sourcepub(crate) async fn set_media_previews_enabled(
&self,
setting: MediaPreviews,
) -> Result<(), ()>
pub(crate) async fn set_media_previews_enabled( &self, setting: MediaPreviews, ) -> Result<(), ()>
Set which rooms display media previews.
Sourcepub(crate) async fn set_invite_avatars_enabled(
&self,
enabled: bool,
) -> Result<(), ()>
pub(crate) async fn set_invite_avatars_enabled( &self, enabled: bool, ) -> Result<(), ()>
Set whether to display avatars in invites.
Sourcepub fn connect_media_previews_enabled_changed<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_media_previews_enabled_changed<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Connect to the signal emitted when the media previews setting changed.